@@ -1,5 +1,5 @@
-# Gufw 13.04.0 - http://gufw.org
-# Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 13.10.0 - http://gufw.org
+# Copyright (C) 2008-2013 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,14 +15,14 @@
 # along with Gufw; if not, see http://www.gnu.org/licenses for more
 # information.
 
-from model.Firewall import Firewall
-
+from frontend import Frontend
+from backend  import Backend
 
 class Controller:
-    
     def __init__(self):
-        self.firewall = Firewall()
-
-    def get_firewall(self):
-        return self.firewall
-        
+        # Check user has access to administrative tools
+        self.backend = Backend()        
+        self.fw_frontend = Frontend(self.backend)
+    
+    def get_fw_frontend(self):
+        return self.fw_frontend
