@@ -1,6 +1,6 @@
 #!/usr/bin/env python
-# Gufw 13.04.0 - http://gufw.org
-# Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 13.10.0 - http://gufw.org
+# Copyright (C) 2008-2013 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,24 +16,22 @@
 # along with Gufw; if not, see http://www.gnu.org/licenses for more
 # information.
 
-from util         import Validation
-from controller   import Controller 
-from view.guiGufw import GuiGufw
+from controller  import Controller 
+from model.utils import InstanceApp
+from view.gufw   import Gufw
 
-
-if __name__ == "__main__":
-    
+if __name__ == '__main__':
     # Check config file & is running previously
-    appInstance = Validation()
+    appInstance = InstanceApp()
     
-    # Controller
+    # Controller & Unlock root GUI
     controler = Controller()
     
     # Firewall
-    firewall = controler.get_firewall()
+    fw_frontend = controler.get_fw_frontend()
     
-    # Show GUI
-    app = GuiGufw(firewall)
+    # GUI
+    app = Gufw(fw_frontend)
     
     # Remove current instance
     appInstance.exit_application()
